==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QCameraFocusControl_shell.h <==
#ifndef QCAMERAFOCUSCONTROL_SHELL_H
#define QCAMERAFOCUSCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qcamerafocuscontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qcamerafocus.h>
#include <QtJambi/RegistryAPI>


class QCameraFocusControl_shell : public QCameraFocusControl, public QtJambiShellInterface
{
public:
    QCameraFocusControl_shell(QObject* parent0 = nullptr);
    ~QCameraFocusControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QPointF customFocusPoint() const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QCameraFocus::FocusModes focusMode() const override;
    QCameraFocus::FocusPointMode focusPointMode() const override;
    QList<QCameraFocusZone> focusZones() const override;
    bool isFocusModeSupported(QCameraFocus::FocusModes mode0) const override;
    bool isFocusPointModeSupported(QCameraFocus::FocusPointMode mode0) const override;
    void setCustomFocusPoint(const QPointF& point0) override;
    void setFocusMode(QCameraFocus::FocusModes mode0) override;
    void setFocusPointMode(QCameraFocus::FocusPointMode mode0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCameraFocusControl_access : public QCameraFocusControl
{
    jobject __qt_customFocusPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_focusMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_focusPointMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_focusZones(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isFocusModeSupported_QCameraFocus_FocusModes_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0) const;
    jboolean __qt_isFocusPointModeSupported_QCameraFocus_FocusPointMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0) const;
    void __qt_setCustomFocusPoint_cref_QPointF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID point0);
    void __qt_setFocusMode_QCameraFocus_FocusModes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
    void __qt_setFocusPointMode_QCameraFocus_FocusPointMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
};

#endif // QCAMERAFOCUSCONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QCameraFocusControl_shell.h <==
#ifndef QCAMERAFOCUSCONTROL_SHELL_H
#define QCAMERAFOCUSCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qcamerafocuscontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qcamerafocus.h>
#include <QtJambi/RegistryAPI>


class QCameraFocusControl_shell : public QCameraFocusControl, public QtJambiShellInterface
{
public:
    QCameraFocusControl_shell(QObject* parent0 = nullptr);
    ~QCameraFocusControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QPointF customFocusPoint() const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QCameraFocus::FocusModes focusMode() const override;
    QCameraFocus::FocusPointMode focusPointMode() const override;
    QList<QCameraFocusZone> focusZones() const override;
    bool isFocusModeSupported(QCameraFocus::FocusModes mode0) const override;
    bool isFocusPointModeSupported(QCameraFocus::FocusPointMode mode0) const override;
    void setCustomFocusPoint(const QPointF& point0) override;
    void setFocusMode(QCameraFocus::FocusModes mode0) override;
    void setFocusPointMode(QCameraFocus::FocusPointMode mode0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCameraFocusControl_access : public QCameraFocusControl
{
    jobject __qt_customFocusPoint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_focusMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_focusPointMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_focusZones_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isFocusModeSupported_QCameraFocus_FocusModes_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0) const;
    jboolean __qt_isFocusPointModeSupported_QCameraFocus_FocusPointMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0) const;
    void __qt_setCustomFocusPoint_cref_QPointF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID point0);
    void __qt_setFocusMode_QCameraFocus_FocusModes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
    void __qt_setFocusPointMode_QCameraFocus_FocusPointMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
};

#endif // QCAMERAFOCUSCONTROL_SHELL_H
